@@ -24,6 +24,7 @@ class FindBrokerSLOHisListRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'CSB', '2017-11-18', 'FindBrokerSLOHisList')
+		self.set_method('GET')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
@@ -34,4 +35,16 @@ class FindBrokerSLOHisListRequest(RpcRequest):
 		return self.get_query_params().get('CsbId')
 
 	def set_CsbId(self,CsbId):
-		self.add_query_param('CsbId',CsbId)
\ No newline at end of file
+		self.add_query_param('CsbId',CsbId)
+
+	def get_BeginDdHHmm(self):
+		return self.get_query_params().get('BeginDdHHmm')
+
+	def set_BeginDdHHmm(self,BeginDdHHmm):
+		self.add_query_param('BeginDdHHmm',BeginDdHHmm)
+
+	def get_EndDdHHmm(self):
+		return self.get_query_params().get('EndDdHHmm')
+
+	def set_EndDdHHmm(self,EndDdHHmm):
+		self.add_query_param('EndDdHHmm',EndDdHHmm)
\ No newline at end of file
